@@ -11,8 +11,8 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 
-Version = '1.8'
-Build = '2'
+Version = '1.9'
+Build = '1'
 
 import sys
 import os
@@ -27,6 +27,7 @@ from PyQt4.QtMaemo5 import *
 from clevenMainUI import *
 from clevenDriversUI import *
 from clevenDecryptUI import *
+from clevenDictionaryUI import *
 from clevenKeysUI import *
 from clevenStartupUI import *
 
@@ -290,14 +291,14 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
     def getKernelVersion(self):
 
        global kernelVersion
-       kernelVersion = os.popen('uname -r').read()
+       kernelVersion = os.popen('uname -r').read().strip('\n').strip('')
        print kernelVersion
        
-       if kernelVersion == '2.6.28.10power46-wl1\n':
+       if kernelVersion == '2.6.28.10power46-wl1':
           pass
-       elif kernelVersion == '2.6.28.10-power47\n':
+       elif kernelVersion == '2.6.28.10-power47':
           pass
-       elif kernelVersion == '2.6.28.10-power48\n':
+       elif kernelVersion == '2.6.28.10-power48':
           pass
        else: 
           message = 'WARNING: The system did not find a compatible kernel version for the injection drivers.\n\nThe application might not work properly..'
@@ -443,7 +444,30 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        ## Set requested setting for "Connect automatically" 
        os.system('gconftool-2 -s --type list --list-type string /system/osso/connectivity/network_type/auto_connect [%s]' % String)
 
-class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
+class clevenSelectDictionary(QtGui.QDialog): # Complete
+
+    def __init__(self, parent=None):
+       ##Build the parent user interface
+       QtGui.QDialog.__init__(self, parent)
+       self.ui = Ui_clevenDictionaryUI()
+       self.ui.setupUi(self)
+       self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+       self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+
+       QtCore.QObject.connect(self.ui.dictionaryList, QtCore.SIGNAL('itemSelectionChanged()'), self.setDictionary)
+       
+       self.ui.dictionaryList.clear()     
+       dlist = os.listdir(pathTemp + '/' + folderDictionaries)
+       self.ui.dictionaryList.addItems(dlist)
+       
+    def setDictionary(self):
+       global myDictionary
+       myDictionary = self.ui.dictionaryList.currentItem().text()
+
+       self.close()
+
+ 
+class clevenDecryptCaptured(QtGui.QMainWindow): # on change
 
     def __init__(self, parent=None):
        ##Build the parent user interface
@@ -459,8 +483,8 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        
        # Decryption
        QtCore.QObject.connect(self.ui.decryptButton, QtCore.SIGNAL('clicked()'), self.decryptORdeleteCapturedFiles)
+       QtCore.QObject.connect(self.ui.dictionaryButton, QtCore.SIGNAL('clicked()'), self.showSelectDictionaryDialog)
        QtCore.QObject.connect(self.ui.capturedList, QtCore.SIGNAL('itemSelectionChanged()'), self.enableDecryptionButtons)
-       QtCore.QObject.connect(self.ui.dictionaryList, QtCore.SIGNAL('itemSelectionChanged()'), self.enableDecryptionButtons)
        QtCore.QObject.connect(self.ui.wepRadio, QtCore.SIGNAL('clicked()'), self.showCapturedFiles)
        QtCore.QObject.connect(self.ui.wpaRadio, QtCore.SIGNAL('clicked()'), self.showCapturedFiles)
        
@@ -470,10 +494,20 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        self.ui.selectCommonRadio.setEnabled(False)
        self.ui.actionEnableDeleteOptions.setEnabled(True)
        self.ui.actionDisableDeleteOptions.setEnabled(False)       
-
+       self.ui.dictionaryLine.setEnabled(False)
+       self.ui.dictionaryButton.setHidden(True)
+       self.ui.dictionaryLine.setHidden(True)
+       
        global deleteModeOn
        deleteModeOn = 'False'
+
+    def showSelectDictionaryDialog(self):
+       '''Open the dictionary selection dialog'''
        
+       DictionariesDialog = clevenSelectDictionary()
+       DictionariesDialog.exec_()
+       self.ui.dictionaryLine.setText(myDictionary)
+
     def enableDecryptionButtons(self):
        '''Enable in the UI the Decrypt button'''
       
@@ -511,12 +545,14 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
       
        if self.ui.wepRadio.isChecked():
           encryption = "WEP"
-          self.ui.dictionaryList.setHidden(True)
-          self.ui.labelDictionaries.setHidden(True)
+          self.ui.dictionaryButton.setHidden(True)
+          self.ui.dictionaryLine.setHidden(True)
+          
        else:
           encryption = "WPA"
-          self.ui.dictionaryList.setHidden(False)
-          self.ui.labelDictionaries.setHidden(False)          
+          if deleteModeOn == 'False':
+            self.ui.dictionaryButton.setHidden(False)
+            self.ui.dictionaryLine.setHidden(False)
 
        self.ui.capturedList.clear() 
        self.ui.decryptButton.setEnabled(False)
@@ -526,12 +562,8 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        clist_clean.sort(key=str.lower)
        self.ui.capturedList.addItems(clist_clean)
 
-       self.ui.dictionaryList.clear()     
-       dlist = os.listdir(pathTemp + '/' + folderDictionaries)
-       self.ui.dictionaryList.addItems(dlist)
-
     def decryptORdeleteCapturedFiles(self):
-       '''Start the decryption of the packets OR Delete captured files saved in the system'''
+       '''Start the decryption OR deletion of the captured files saved in the system'''
 
        if self.ui.capturedList.currentRow() == -1:
           self.ui.decryptButton.setEnabled(False)
@@ -550,13 +582,13 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
              cap = self.capfile.strip()
              key = self.capfile.strip()
           # print "cap: ", cap
-          # print "key: ", key   
+          # print "key: ", key 
+          
           if self.ui.wpaRadio.isChecked():
-             if self.ui.dictionaryList.currentRow() == -1:
+             if myDictionary == '':
                 self.ui.decryptButton.setEnabled(False)
                 return
              else:
-                myDictionary = self.ui.dictionaryList.currentItem().text()
                 os.system('osso-xterm -e "sudo %s/%s decryptWPA %s %s %s %s" &' % (pathMain, helperScript, pathTemp, myDictionary, key, cap))
           else:
              # print pathMain, pathTemp, key, cap
@@ -564,8 +596,8 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        
        ##Delete files             
        elif deleteModeOn == 'True':
-          self.ui.dictionaryList.setHidden(True)
-          self.ui.labelDictionaries.setHidden(True)
+          self.ui.dictionaryButton.setHidden(True)
+          self.ui.dictionaryLine.setHidden(True)
 
           if self.ui.wepRadio.isChecked():
              encryption = "WEP"
